validate_supplied_evidence_ref

Function validate_supplied_evidence_ref 

pub fn validate_supplied_evidence_ref(
    about: &str,
    path: &str,
    evidence_ref: &str,
) -> Result<(), String>
Evidence nodes use a distinct prefix, but remain owned by exactly one about through the entry ref embedded after evidence:.