pub fn validate_supplied_member_ref(
about: &str,
path: &str,
member_ref: &str,
) -> Result<(), String>Expand description
A relation-like ref may name the about anchor, one of its entry nodes, an owned evidence node, or the canonical namespace used for its dimensions.