crosses_abouts

Function crosses_abouts 

pub fn crosses_abouts(
    about: &str,
    relation: &MemoryRelationData,
    relation_type: &MemoryRelationType,
    target_ref: &str,
) -> bool
Whether a relation is the one that may cross an about: same_event_as or same_entity_as, evidential, with why and evidence, stamped as declared from a kmp_relate proposal, to a ref this about does not own.