pub struct KernelMemoryApplicationService<G, D, S, E, W> { /* private fields */ }Implementations
Sourceimpl<G, D, S, E, W> KernelMemoryApplicationService<G, D, S, E, W>
impl<G, D, S, E, W> KernelMemoryApplicationService<G, D, S, E, W>
pub fn new( query_application: Arc<QueryApplicationService<G, D, S>>, command_application: Arc<CommandApplicationService<E, W>>, ) -> Self
Sourceimpl<G, D, S, E, W> KernelMemoryApplicationService<G, D, S, E, W>where
G: GraphNeighborhoodReader + MemoryAboutIndexReader + NodeRelationshipReader + Send + Sync,
D: NodeDetailReader + Send + Sync,
S: SnapshotStore + Send + Sync,
E: ContextEventStore + Send + Sync,
W: ProjectionWriter + Send + Sync,
impl<G, D, S, E, W> KernelMemoryApplicationService<G, D, S, E, W>where
G: GraphNeighborhoodReader + MemoryAboutIndexReader + NodeRelationshipReader + Send + Sync,
D: NodeDetailReader + Send + Sync,
S: SnapshotStore + Send + Sync,
E: ContextEventStore + Send + Sync,
W: ProjectionWriter + Send + Sync,
pub async fn ingest( &self, command: MemoryIngestCommand, ) -> Result<MemoryIngestOutcome, ApplicationError>
Sourcepub async fn list_abouts(&self) -> Result<Vec<String>, ApplicationError>
pub async fn list_abouts(&self) -> Result<Vec<String>, ApplicationError>
The abouts the memory currently indexes, for consumers that render an index of what can be recalled — a viewer’s sidebar, a CLI listing.
pub async fn wake( &self, query: WakeMemoryQuery, ) -> Result<GetContextResult, ApplicationError>
pub async fn ask( &self, query: AskMemoryQuery, ) -> Result<GetContextResult, ApplicationError>
pub async fn temporal( &self, query: TemporalMemoryQuery, ) -> Result<TemporalMemoryResult, ApplicationError>
pub async fn trace( &self, query: TraceMemoryQuery, ) -> Result<GetContextPathResult, ApplicationError>
pub async fn inspect( &self, query: InspectMemoryQuery, ) -> Result<InspectMemoryResult, ApplicationError>